#!/usr/bin/env python

# Copyright (C) 2011, Aleksey Lim
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import sys
from optparse import OptionParser
from os.path import dirname, abspath, basename, join, exists
from gettext import gettext as _


def cmd_dev():
    root = abspath(dirname(__file__))

    for i in ['Server', 'Backup', 'Statistics']:
        service_filename = 'org.sugarlabs.client.%s.service' % i

        service = []
        for i in file(join(root, service_filename + '.in')).read().split('\n'):
            i = i.replace('@bindir@', root)
            if i.startswith('Exec'):
                i += ' -DD'
            service.append(i)

        service_dir = join(os.environ['HOME'], '.local', 'share', 'dbus-1',
                'services')
        if not exists(service_dir):
            os.makedirs(service_dir)

        service_file = file(join(service_dir, service_filename), 'w')
        service_file.write('\n'.join(service))
        service_file.close()


HELP = """
Commands:
  dev                   install required files in development environment

See http://wiki.sugarlabs.org/go/Sugar_Server_Kit/sugar-client for details."""


parser = OptionParser(
        usage='%prog [OPTIONS] [COMMAND]',
        description=_('Development routines for sugar-client.'),
        add_help_option=False)
parser.add_option('-h', '--help',
        help=_('show this help message and exit'),
        action='store_true')

options, args = parser.parse_args()

if not args and not options.help:
    prog = basename(sys.argv[0])
    print 'Usage: %s [OPTIONS] [COMMAND]' % prog
    print '       %s -h|--help' % prog
    print
    print parser.description
    print HELP
    exit(0)

if options.help:
    parser.print_help()
    print HELP
    exit(0)

command = args.pop(0)
if 'cmd_' + command not in globals():
    print _('Unknown command "%s"') % command
    exit(1)
exit(globals()['cmd_' + command]() or 0)
