# Copyright (C) 2011, Aleksey Lim
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import logging
import subprocess
from glob import glob
from gettext import gettext as _

from sugar_client.util import enforce


_logger = logging.getLogger('yum')


class Packager(object):

    reboot_packages = [
            'kernel', 'kernel-firmware',
            ]

    relogin_packages = [
            'sugar', 'sugar-artwork', 'sugar-base', 'sugar-datastore',
            'sugar-presence-service', 'sugar-toolkit',
            ]

    def __init__(self, config_path, environ):
        self._config_path = config_path or '/etc/yum.conf'
        self._environ = environ

    def cleanup(self):
        _logger.debug('Compelete transactions')
        code, __ = self._call('/usr/sbin/yum-complete-transaction', '-y')
        if code == 0:
            return

        _logger.debug('Transactions completion failed, ' \
                'remove possibly broken rpmdb')
        for i in glob('/var/lib/rpm/__db.*'):
            os.unlink(i)
        code, __ = self._call('/usr/sbin/yum-complete-transaction', '-y')
        if code == 0:
            return

        _logger.debug('Transactions still failed, clean them up')
        code, __ = self._call('/usr/sbin/yum-complete-transaction', '-y',
                '--cleanup-only')

    def to_update(self):
        code, stdout = self._call('/usr/bin/yum', '-e0', 'check-update')
        if code == 0:
            return []
        elif code == 100:
            return [i.split()[0] for i in str(stdout).split('\n') if i.strip()]
        else:
            raise RuntimeError(_('Cannot get list of packages to update'))

    def update(self):
        code, __ = self._call('/usr/bin/yum', '-y', 'update')
        enforce(code == 0, _('Cannot upgrade system'))

    def last_updated(self):
        return int(os.stat('/var/lib/rpm/Packages').st_mtime)

    def _call(self, command, *args):
        args = [command, '--skip-broken', '--quiet', '--tolerant',
                '-c', self._config_path] + list(args)
        process = subprocess.Popen(args, env=self._environ,
                stderr=subprocess.PIPE, stdout=subprocess.PIPE)
        stdout, stderr = process.communicate()
        _logger.debug('Call %r stdout=%r stderr=%r', args, stdout, stderr)
        return process.returncode, stdout
