# Copyright (C) 2011, Aleksey Lim
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import logging


status = None
percent = None

status_changed_cb = lambda: None
percent_changed_cb = lambda: None

_total = None
_done = None


def info(message, *args):
    """Log translated message."""
    global status
    if args:
        message = message % args
    if message == status:
        return
    logging.info(message)
    status = message
    status_changed_cb()


def reset():
    """Reset total progress before calling `increment_total()`."""
    global _total, _done, status, percent
    status = None
    _total = 0
    _done = 0
    percent = 0.0


def increment_total(steps=1):
    """Increment global total progress."""
    global _total
    _total += float(steps)


def increment(done=1, **kwargs):
    """Change global progress.

    :param done:
        number of steps to increment global progress

    """
    global _done, percent
    _done += done
    new_percent = min(100, int(_done / _total * 100))
    if new_percent == percent:
        return
    percent = new_percent
    percent_changed_cb()
