#!/usr/bin/env python

# sugar-lint: disable

import os
import sys
import time
import xmlrpclib
from ConfigParser import ConfigParser
from os.path import exists, relpath, abspath, isfile, isdir

import gtk

sys.path.insert(0, '..')
import tests
from tests import Test, main
from sugar_client import env, backup


class ServerTest(Test):

    def setUp(self):
        Test.setUp(self)
        backup._RSYNC = '/usr/bin/rsync'
        self.exit = None

        def finished_cb(exit):
            self.exit = exit
            gtk.main_quit()

        self.service = backup.Service()
        self.service.Finished = lambda exit: finished_cb(exit)

    def tearDown(self):
        self.service.remove_from_connection()
        self.service = None
        Test.tearDown(self)

    def test_Backup_LocalDestination(self):
        self.touch('.sugar/default/datastore/test')
        self.service.Backup('dst', 0)
        gtk.main()
        self.assertEqual(0, self.exit)
        assert exists('dst/test')

    def test_Backup_ExcludeIndex(self):
        self.touch(
                '.sugar/default/datastore/index/',
                '.sugar/default/datastore/index_updated',
                )
        self.service.Backup('dst', 0)
        gtk.main()
        self.assertEqual(0, self.exit)
        assert not exists('dst/index')
        assert not exists('dst/index_updated')

    def test_Backup_Timeout(self):
        self.httpd(8080, ('/test', 503),
                         ('/test', 503),
                         ('/test', 503),
                         )
        env.backup_url.value = 'localhost:/foo'
        env.backup_availability_url.value = 'http://localhost:8080/test'
        backup._BACKUP_SERVER_TIMEOUT = lambda x: x + 1
        self.service.Backup('', 3)
        gtk.main()
        assert self.exit is not None and self.exit != 0

    def test_Restore_LocalDestination(self):
        self.touch('src/test')
        self.service.Restore('src', 0)
        gtk.main()
        assert exists('.sugar/default/datastore/test')

    def test_Restore_RemoveIndex(self):
        self.touch(
                '.sugar/default/datastore/index/',
                '.sugar/default/datastore/index_updated',
                'src/',
                )
        self.service.Restore('src', 0)
        gtk.main()
        assert not exists('.sugar/default/datastore/index')
        assert not exists('.sugar/default/datastore/index_updated')

    def test_Cancel(self):
        self.touch(('rsync', '#!/bin/sh\nsleep 10'))
        os.chmod('rsync', 0755)
        backup._RSYNC = tests.tmpdir + '/rsync'

        self.service.Backup('dst', 0)
        self.service.Cancel()
        ts = time.time()
        gtk.main()
        assert time.time() - ts < 10

        self.service.Restore('src', 0)
        self.service.Cancel()
        ts = time.time()
        gtk.main()
        assert time.time() - ts < 10


if __name__ == '__main__':
    main()
