#!/usr/bin/env python

# sugar-lint: disable

import os
import sys
import pwd
from os.path import exists, relpath, abspath, isfile, isdir

import gconf

sys.path.insert(0, '..')
import tests
from tests import Test, main
from sugar_client import env


class EnvTest(Test):

    def setUp(self):
        Test.setUp(self)

        self.chowned = []
        self.override(os, 'chown', lambda *args: self.chowned.append(args))

    def test_var_path_NonRootUser(self):
        self.assertRaises(RuntimeError, env.var_path, 'foo/bar')
        self.assertEqual(tests.tmpdir + '/tmp/foo', env.var_path('foo'))
        assert not exists('tmp/bar')

    def test_var_path_RootUser(self):
        self.override(os, 'geteuid', lambda: 0)

        self.assertEqual(tests.tmpdir + '/tmp/bar', env.var_path('bar'))
        assert isfile('tmp/bar')
        user = pwd.getpwnam(env.user.value)
        self.assertEqual(
                [(tests.tmpdir + '/tmp/bar', user.pw_uid, user.pw_gid)],
                self.chowned)

    def test_profile_path_NonRootUser(self):
        env.profile_path('foo', 'bar')
        assert isdir('.sugar/default/foo')
        assert not exists('.sugar/default/foo/bar')

    def test_profile_path_RootUser(self):
        self.override(os, 'geteuid', lambda: 0)

        env.profile_path('foo', 'bar')
        assert isfile('.sugar/default/foo/bar')
        user = pwd.getpwnam(env.user.value)
        self.assertEqual(
                sorted([(tests.tmpdir + '/.sugar', user.pw_uid, user.pw_gid),
                        (tests.tmpdir + '/.sugar/default', user.pw_uid, user.pw_gid),
                        (tests.tmpdir + '/.sugar/default/foo', user.pw_uid, user.pw_gid),
                        (tests.tmpdir + '/.sugar/default/foo/bar', user.pw_uid, user.pw_gid),
                        ]),
                sorted(self.chowned))

    def test_flock(self):
        lock = env.flock('foo')
        self.assertEqual(tests.tmpdir + '/tmp/sugar-client-foo.lock', lock.name)
        assert exists(lock.name)

        self.assertRaises(RuntimeError, env.flock, 'foo')

        lock_2 = env.flock('bar')
        assert exists(lock_2.name)

    def test_http_proxy(self):
        conf = gconf.client_get_default()

        conf.set_bool('/system/http_proxy/use_http_proxy', False)
        self.assertEqual(None, env.http_proxy())

        conf.set_bool('/system/http_proxy/use_http_proxy', True)
        conf.set_string('/system/http_proxy/host', 'host')
        conf.set_int('/system/http_proxy/port', 8)
        conf.set_bool('/system/http_proxy/use_authentication', False)
        self.assertEqual('http://host:8', env.http_proxy())

        conf.set_bool('/system/http_proxy/use_authentication', True)
        conf.set_string('/system/http_proxy/authentication_user', 'user')
        conf.set_string('/system/http_proxy/authentication_password', 'password')
        self.assertEqual('http://user:password@host:8', env.http_proxy())


if __name__ == '__main__':
    main()
