#!/usr/bin/env python

# sugar-lint: disable

import sys
import xmlrpclib
from ConfigParser import ConfigParser

import gtk

sys.path.insert(0, '..')
import tests
from tests import Test, main
from sugar_client import env, server


class ServerTest(Test):

    def setUp(self):
        Test.setUp(self)
        self.service = server.Service()

    def tearDown(self):
        self.service.remove_from_connection()
        self.service = None
        Test.tearDown(self)

    def test_Register(self):
        registered = []

        class Reply(dict):

            def new(self, url):
                self.url = url
                return self

            def register(self, serial, nick, uuid, pubkey):
                registered.append((self.url, serial, nick, uuid, pubkey))
                config = {'jabber': 'test_jabberserver',
                          'backup-url': 'test_backupurl',
                          'backup-availability-url': 'test_backup_availability_url',
                          'pms-config': 'test_pms_config',
                          }
                return {'success': 'OK', 'config': config}

        self.override(xmlrpclib, 'ServerProxy', lambda url: Reply().new(url))

        self.assertRaises(RuntimeError, self.service.Register, 'localhost:8080')

        self.touch('.sugar/default/owner.key.pub')
        self.assertRaises(RuntimeError, self.service.Register, 'localhost:8080')

        self.touch(('.sugar/default/owner.key.pub', 'ssh-dss pubkey'))
        reply = self.service.Register('test')
        self.assertEqual(
                [('test', env.serial(), env.nick(), env.uuid(), 'pubkey')],
                registered)
        self.assertEqual('test_jabberserver', env.gconf_get('/desktop/sugar/collaboration/jabber_server'))

        config = ConfigParser()
        config.read('.sugar/default/sugar-client.conf')
        self.assertEqual('test_jabberserver', config.get('main', 'jabber'))
        self.assertEqual('test_backupurl', config.get('main', 'backup-url'))
        self.assertEqual('test_backup_availability_url', config.get('main', 'backup-availability-url'))
        self.assertEqual('test_pms_config', config.get('main', 'pms-config'))

        self.assertEqual('test_jabberserver', env.jabber.value)
        self.assertEqual('test_backupurl', env.backup_url.value)
        self.assertEqual('test_backup_availability_url', env.backup_availability_url.value)
        self.assertEqual('test_pms_config', env.pms_config.value)


if __name__ == '__main__':
    main()
