#!/usr/bin/env python

# sugar-lint: disable

import os
import sys
import pwd
from os.path import exists, relpath, abspath, isfile, isdir

import gtk
import dbus

sys.path.insert(0, '..')
import tests
from tests import Test, main
from sugar_client import env, system, pms


class Pms(object):

    updates = []
    updated = []
    reboot_packages = []
    relogin_packages = []

    def to_update(self):
        return Pms.updates

    def cleanup(self):
        pass

    def update(self):
        Pms.updated.append(True)
        del Pms.updates[:]


class SystemTest(Test):

    def setUp(self):
        Test.setUp(self)
        self.override(pms, 'get', lambda *args: Pms())

        Pms.updates = []
        Pms.updated = []
        Pms.reboot_packages = []
        Pms.relogin_packages = []

        env.pms_config.value = 'fake'
        system._STAMP_PATH = 'stamp'
        self.exit = None

        def finished_cb(exit):
            self.exit = exit
            gtk.main_quit()

        self.service = system.Service()
        self.service.Finished = lambda exit: finished_cb(exit)

    def tearDown(self):
        self.service.remove_from_connection()
        self.service = None
        Test.tearDown(self)

    def test_Update_NoPMSConfig(self):
        env.pms_config.value = None
        self.assertRaises(RuntimeError, self.service.Update, True)

    def test_Update_NoUpdates(self):
        self.service.Update(False)
        gtk.main()
        self.assertEqual(0, self.exit)
        self.assertEqual([], Pms.updated)
        assert exists('stamp')

    def test_Update(self):
        Pms.updates = ['foo']
        self.service.Update(False)
        gtk.main()
        self.assertEqual(0, self.exit)
        self.assertEqual(1, len(Pms.updated))
        assert exists('stamp')

    def test_Update_OnlyOnce(self):
        Pms.updates = ['foo']
        self.service.Update(False)
        gtk.main()
        self.assertEqual(0, self.exit)
        self.assertEqual(1, len(Pms.updated))
        assert exists('stamp')

        Pms.updates = ['foo']
        self.service.Update(False)
        gtk.main()
        self.assertEqual(0, self.exit)
        self.assertEqual(1, len(Pms.updated))

        os.utime('stamp', (0, 0))
        Pms.updates = ['foo']
        self.service.Update(False)
        gtk.main()
        self.assertEqual(0, self.exit)
        self.assertEqual(2, len(Pms.updated))

        Pms.updates = ['foo']
        self.service.Update(False)
        gtk.main()
        self.assertEqual(0, self.exit)
        self.assertEqual(2, len(Pms.updated))

        os.unlink('stamp')
        Pms.updates = ['foo']
        self.service.Update(False)
        gtk.main()
        self.assertEqual(0, self.exit)
        self.assertEqual(3, len(Pms.updated))
        assert exists('stamp')

    def _test_Update_NeedToReboot(self):
        self.to_quit = 1

        system_bus = dbus.SystemBus()
        system_bus.add_signal_receiver(lambda *args: self.main_quit, 'Reboot', 'org.sugarlabs.system')

        Pms.reboot_packages = ['reboot']
        Pms.updates = ['reboot']
        self.service.Update(True)
        gtk.main()
        self.assertEqual(0, self.exit)


if __name__ == '__main__':
    main()
